/// <reference path="../Definitions/jquery.d.ts"/>
/// <reference path="../Definitions/knockout.d.ts"/>
/// <reference path="../Definitions/knockout.mapping.d.ts"/>
/// <reference path="../Definitions/SharePoint.d.ts"/>

var utility;
(function (utility) {
    /** fixes MS.AJAX's funny date to a javascript date object */
    function fixDate(value) {
        var rd = new RegExp("Date\\([\\d+-]+\\)");
        var m = rd.exec(value);
        if (m) {
            return eval("new " + m[0]);
        }
    }
    utility.fixDate = fixDate;

    /** splits a picture path to find the thumbnail image url */
    function getThumbnailUrl(url) {
        // http://spg-dev-jl/PublishingImages/Photo%20(2).jpg
        // http://spg-dev-jl/PublishingImages/_w/Photo%20(2)_jpg.jpg
        var re = /(.*)\/([^\/]*)\.(.*)/gi;
        var m = re.exec(url);
        if (m) {
            return m[1] + "/_w/" + m[2] + "_" + m[3] + ".jpg";
        }
        return url;
    }
    utility.getThumbnailUrl = getThumbnailUrl;

    /** splits a SPFieldLink into two arguments */
    function cleanSPFieldLink(link) {
        var re = /^(.*), /gi;
        var m = re.exec(link);
        if (m)
            return m[1];
        return link;
    }
    utility.cleanSPFieldLink = cleanSPFieldLink;
})(utility || (utility = {}));

// Module
var PInteresp;
(function (PInteresp) {
    // Class
    var PictureItemViewModel = (function () {
        function PictureItemViewModel(data) {
            var _this = this;
            // after TS 0.9, this line will be:
            // public name : KnockoutObservable<string> = ko.observable("");
            this.name = ko.observable("");
            this.name1 = "";
            // public width : KnockoutObservable<number> = ko.observable(0);
            this.width = ko.observable(0);
            this.height = ko.observable(0);
            this.createdBy = ko.observable("");
            this.createdByPicture = ko.observable("");
            this.modifiedOn = ko.observable(null);
            this.src = ko.observable("");
            this.name(data.Name);
            this.width(data.Width);
            this.height(data.Height);
            this.createdBy(data.CreatedBy ? data.CreatedBy.Name : "");
            this.createdByPicture(data.CreatedBy && data.CreatedBy.Picture ? utility.cleanSPFieldLink(data.CreatedBy.Picture) : "/_layouts/images/O14_person_placeHolder_96.png");
            this.modifiedOn(utility.fixDate(data.Modified));
            this.src(data.__metadata.media_src);

            this.srcComputed = ko.computed(function () {
                return utility.getThumbnailUrl(_this.src());
            });
        }
        PictureItemViewModel.prototype.view = function () {
            SP.UI.ModalDialog.showModalDialog({
                url: this.src(),
                title: this.name()
            });
        };

        PictureItemViewModel.prototype.getUser = function () {
            alert(this.createdBy());
        };

        PictureItemViewModel.prototype.like = function () {
            // not implmented yet!
        };
        return PictureItemViewModel;
    })();
    PInteresp.PictureItemViewModel = PictureItemViewModel;

    // rename symbol
    var PicturesLibraryViewModel = (function () {
        function PicturesLibraryViewModel() {
            // knockout uses a mapping object when cloning child objects
            this.mapping = {
                create: function (options) {
                    return new PictureItemViewModel(options.data);
                }
            };
            this.items = ko.mapping.fromJS([], this.mapping);
        }
        /**
        * call rest interface and load the viewmodel with a set of pictures
        */
        PicturesLibraryViewModel.prototype.load = function () {
            var self = this;
            var restUrl = _spPageContextInfo.webServerRelativeUrl + "_vti_bin/listdata.svc/Images/?$expand=CreatedBy&$select=Name,Width,Height,CreatedBy,Modified";

            $.ajax({
                type: "GET",
                url: restUrl,
                contentType: "application/json; charset=utf-8",
                dataType: "json",
                cache: false,
                processData: true,
                success: function (data, status, xhr) {
                    if (status == "success" && data) {
                        // using knockout mapping to map json objects into
                        // knockout observable array
                        ko.mapping.fromJS(data.d.results, self.mapping, self.items);
                    }
                },
                error: function (xhr, status, err) {
                    alert(err);
                }
            });
        };

        PicturesLibraryViewModel.prototype.wookmark = function () {
            $('div.pictures div.listitem').wookmark({ offset: 15, container: $('div.pictures'), autoResize: true });
        };
        return PicturesLibraryViewModel;
    })();
    PInteresp.PicturesLibraryViewModel = PicturesLibraryViewModel;
})(PInteresp || (PInteresp = {}));

var vm = new PInteresp.PicturesLibraryViewModel();
$(document).ready(function () {
    ko.applyBindings(vm);
    vm.load();
});
// toggle outline expansion
// checkout sourcemap
//# sourceMappingURL=pinteresp.js.map
