/// <reference path="../Definitions/jquery.d.ts"/>
/// <reference path="../Definitions/SharePoint.d.ts"/>

// http://www.typescriptlang.org/Playground/
module TypeChecking {

    function f1(x, y) {
        return x + y;
    }

    function f2(x: number, y: number) : number {
        return x + y;
        //return "";
    }

    f1(1, 2);
    f1("xx", "yy");
    f2(1, 2);
    //f2("xx", "yy");
    
}

module Interfaces {

    export interface Animal {
        name: string;
    }

    export interface Feline extends Animal {
        speak(): void;
    }

    export class Cat implements Feline {

        name = "";
        
        private age: number;

        constructor(name: string) {
            this.name = name;
            this.age = 3;
        }

        speak() {
            console.log("meow!");
        }
    };

    export class Lion extends Cat {

        speak() {
            console.log("rawr!");
        }
    }

    var catGarfield = new Cat("Garfield");
    
    // Cat is a Type - so this assignment is invalid.
    //var c3: Cat = { name: "Sylvester", speak: function () { } };

    // Interface however, are type-checked by "shape" of the object.  And this is perfectly fine.
    var c2: Feline = { name: "Sylvester", speak: function () { } };
    
    var l1: Lion = new Lion("Simba");
    l1.speak();
}

// ok... this is cool.  what about JQuery

module JQueryModule {

    class MyClass {

        MyMethod1() {
            // jQuery demo

            $("div.class").addClass("xx");
            $("div.class").addClass("xxx").removeClass("yyy");

            $.ajax({
                url: "/_vti_bin/listdata.svc/Announcement",
                success: function (data, status, xhr) {

                }

            });

            $("div.class").click(function (e) {
                e.preventDefault();
                this;  // this is any
            });

            // ECMA Script v6 arrow function syntax - looks just like C# delegates
            $("a.class").click((e) => {
                e.preventDefault();
                this; // this is scoped to the current instance of JQClass
            });
        }
    }
}

/*
module Interfaces {

    
    //  interface, and modules are Open, so you can extend an interface in a different file.
    //  this is most useful for describing javascript libraries, e.g. jQuery, and then jQuery.UI that extends jQuery.
    export interface Feline {
        flip?: () => any;
    }
    
}
*/

module demo {

    export function ShowDialog() {
        // see Definitions
        var options: SP.UI.IDialogOptions = {
            url: "/Pages/demo.aspx",
            title: "Demo Page"            
        };

        SP.UI.ModalDialog.showModalDialog(options);

        // break Url argument
        var dialog = SP.UI.ModalDialog.showModalDialog({ url: "/Pages/demo.aspx", title: "Demo Page" });

        setTimeout(function () {
            dialog.close(SP.UI.DialogResult.OK);
        }, 5000);

        return demo.MyMethod1x();
    }

    function MyPrivateMethod1() {
        return 0;  // scope visibility
    }

    export function MyMethod1x() {
        return 1; // rename
    }

}
